==> nextcloud-20.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_external/l10n/hr.js <==
OC.L10N.register(
    "files_external",
    {
    "External storages" : "Vanjsko spremište za pohranu",
    "Personal" : "Osobno",
    "System" : "Sustav",
    "Grant access" : "Dodijeli pristup",
    "Error configuring OAuth1" : "Pogreška pri konfiguriranju OAuth1",
    "Please provide a valid app key and secret." : "Unesite važeći ključ aplikacije i tajnu.",
    "Error configuring OAuth2" : "Pogreška pri konfiguriranju OAuth2",
    "Generate keys" : "Generiraj ključeve",
    "Error generating key pair" : "Pogreška pri generiranju parova ključeva",
    "All users. Type to select user or group." : "Svi korisnici. Započnite unos za izbor korisnika ili grupe.",
    "(group)" : "(grupa)",
    "Compatibility with Mac NFD encoding (slow)" : "Kompatibilnost s kodiranjem Mac NFD (sporo)",
    "Enable encryption" : "Omogući šifriranje",
    "Enable previews" : "Omogući pretpregled",
    "Enable sharing" : "Omogući dijeljenje",
    "Check for changes" : "Provjeri za promjene",
    "Never" : "Nikad",
    "Once every direct access" : "Jednom za svaki izravni pristup",
    "Read only" : "Samo za čitanje",
    "Delete" : "Izbriši",
    "Admin defined" : "Definira administrator",
    "Are you sure you want to delete this external storage?" : "Jeste li sigurni da želite izbrisati ovu vanjsku pohranu?",
    "Delete storage?" : "Želite li izbrisati pohranu?",
    "Saved" : "Spremljeno",
    "Saving …" : "Spremanje...",
    "Save" : "Spremi",
    "Empty response from the server" : "Prazan odgovor poslužitelja",
    "Couldn't access. Please log out and in again to activate this mount point" : "Nije moguće pristupiti. Odjavite se i ponovno se prijavite kako biste aktivirali ovu točku postavljanja",
    "Couldn't get the information from the remote server: {code} {type}" : "Nisu primljeni podaci s udaljenog poslužitelja: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Nije primljen popis vanjskih točaka postavljanja: {type}",
    "There was an error with message: " : "Došlo je do pogreške s porukom: ",
    "External mount error" : "Pogreška vanjskog postavljanja",
    "external-storage" : "vanjsko spremište za pohranu",
    "Couldn't fetch list of Windows network drive mount points: Empty response from server" : "Nije moguće dohvatiti popis točaka postavljanja mrežnog diska u sustavu Windows: prazan odgovor poslužitelja",
    "Please enter the credentials for the {mount} mount" : "Unesite vjerodajnice postav {mount}",
    "Username" : "Korisničko ime",
    "Password" : "Zaporka",
    "Credentials saved" : "Vjerodajnice su spremljene",
    "Credentials saving failed" : "Neuspješno spremanje vjerodajnica",
    "Credentials required" : "Potrebne su vjerodajnice",
    "Storage with ID \"%d\" not found" : "Pohrana s ID-om „%d” nije pronađena",
    "Invalid backend or authentication mechanism class" : "Nevažeća klasa pozadine ili mehanizma autentifikacije",
    "Invalid mount point" : "Nevažeća točka postavljanja",
    "Objectstore forbidden" : "Zabranjen Objectstore",
    "Invalid storage backend \"%s\"" : "Nevažeća pozadina pohrane „%s”",
    "Not permitted to use backend \"%s\"" : "Nije dopušteno korištenje pozadine „%s”",
    "Not permitted to use authentication mechanism \"%s\"" : "Nije dopušteno korištenje mehanizma autentifikacije „%s”",
    "Unsatisfied backend parameters" : "Neispunjeni sigurnosni parametri",
    "Unsatisfied authentication mechanism parameters" : "Neispunjeni parametri mehanizma autentifikacije",
    "Insufficient data: %s" : "Nedovoljno podataka: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not user editable" : "Korisnici ne mogu uređivati pohranu s ID-om „%d”",
    "Access key" : "Pristupni ključ",
    "Secret key" : "Tajni ključ",
    "Builtin" : "Ugrađen",
    "None" : "Nema",
    "OAuth1" : "OAuth1",
    "App key" : "Ključ aplikacije",
    "App secret" : "Tajna aplikacije",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID klijenta",
    "Client secret" : "Tajni ključ klijenta",
    "OpenStack v2" : "OpenStack v2",
    "Tenant name" : "Ime stanara",
    "Identity endpoint URL" : "URL krajnje točke identiteta",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Domena",
    "Rackspace" : "Rackspace",
    "API key" : "Ključ API-ja",
    "Global credentials" : "Globalne vjerodajnice",
    "Log-in credentials, save in database" : "Vjerodajnice za prijavu, spremi u bazu podataka",
    "Username and password" : "Korisničko ime i zaporka",
    "Log-in credentials, save in session" : "Vjerodajnice za prijavu, spremi u sesiju",
    "Global credentials, user entered" : "Globalne vjerodajnice, unio korisnik",
    "User entered, store in database" : "Unio korisnik, pohrani u bazu podataka",
    "RSA public key" : "Javni ključ RSA",
    "Public key" : "Javni ključ",
    "RSA private key" : "Privatni ključ RSA",
    "Private key" : "Privatni ključ",
    "Kerberos ticket" : "Kerberos ticket",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Naziv poslužitelja",
    "Port" : "Port",
    "Region" : "Regija",
    "Enable SSL" : "Omogući SSL",
    "Enable Path Style" : "Omogući Path Style",
    "Legacy (v2) authentication" : "Naslijeđena (v2) autentifikacija",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Udaljena podmapa",
    "Secure https://" : "Siguran https://",
    "FTP" : "FTP",
    "Host" : "Glavno računalo",
    "Secure ftps://" : "Siguran ftps://",
    "Local" : "Lokalno",
    "Location" : "Lokacija",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Korijen",
    "SFTP with secret key login" : "SFTP s prijavom putem tajnog ključa",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Dijeli",
    "Show hidden files" : "Prikaz skrivenih datoteka",
    "Verify ACL access when listing files" : "Provjeri ACL pristup pri pregledu popisa datoteka",
    "Check the ACL's of each file or folder inside a directory to filter out items where the user has no read permissions, comes with a performance penalty" : "Provjerava ACL-ove pojedinih datoteka ili mapa unutar direktorija radi filtriranja stavki za koje korisnik nema pravo pristupa, opterećuje rad sustava",
    "Timeout" : "Istek vremena",
    "SMB / CIFS using OC login" : "SMB / CIFS s prijavom putem OC-a",
    "Username as share" : "Korisničko ime kao dijeljenje",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Naziv servisa",
    "Request timeout (seconds)" : "Istek zahtjeva (u sekundama)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Podrška za cURL u PHP-u nije omogućena niti instalirana. Nije moguće postaviti %s. Zatražite od svog administratora sustava da je instalira.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Podrška za FTP u PHP-u nije omogućena niti instalirana. Nije moguće postaviti %s. Zatražite od svog administratora sustava da je instalira.",
    "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "„%1$s” nije instaliran. Nije moguće postaviti %2$s. Zatražite od svog administratora sustava da ga instalira.",
    "External storage support" : "Podrška za vanjsku pohranu",
    "Adds basic external storage support" : "Dodaje osnovnu podršku za vanjsku pohranu",
    "This application enables administrators to configure connections to external storage providers, such as FTP servers, S3 or SWIFT object stores, other Nextcloud servers, WebDAV servers, and more. Administrators can choose which types of storage to enable and can mount these storage locations for a user, a group, or the entire system. Users will see a new folder appear in their root Nextcloud directory, which they can access and use like any other Nextcloud folder. External storage also allows users to share files stored in these external locations. In these cases, the credentials for the owner of the file are used when the recipient requests the file from external storage, thereby ensuring that the recipient can access the shared file.\n\nExternal storage can be configured using the GUI or at the command line. This second option provides the advanced user with more flexibility for configuring bulk external storage mounts and setting mount priorities. More information is available in the external storage GUI documentation and the external storage Configuration File documentation." : "Ova aplikacija omogućuje administratorima da konfiguriraju veze s vanjskim davateljima prostora za pohranu, kao što su FTP poslužitelji, S3 ili SWIFT trgovine objektima, drugi Nextcloudovi poslužitelji, WebDAV poslužitelji itd. Administratori mogu odabrati koje vrste prostora za pohranu žele omogućiti i mogu postaviti te prostore za pohranu za pojedinog korisnika, grupu ili cijeli sustav. Korisnici će vidjeti svoju novu mapu koja se pojavi u njihovom korijenskom Nextcloudovom direktoriju i mogu joj pristupiti i upotrebljavati je kao i bilo koju drugu mapu u sustavu Nextcloud. Vanjska pohrana također omogućuje korisnicima dijeljenje datoteka pohranjenih na tim vanjskim lokacijama. U tim se slučajevima koristi vjerodajnica vlasnika datoteke kada primatelj zatraži datoteku iz vanjske pohrane, čime se osigurava da primatelj može pristupiti dijeljenoj datoteci.\n\nVanjska pohrana može se konfigurirati s pomoću GUI-ja ili naredbenog retka. Ova druga opcija naprednom korisniku pruža veću fleksibilnost za konfiguriranje skupnoga vanjskog prostora za pohranu i postavljanje prioriteta pri postavljanju pohrane. Više informacija možete pronaći u dokumentaciji GUI-ja vanjske pohrane i dokumentaciji konfiguracijske datoteke za vanjsku pohranu.",
    "No external storage configured or you don't have the permission to configure them" : "Nema konfigurirane vanjske pohrane ili nemate dopuštenje za konfiguriranje",
    "Name" : "Naziv",
    "Storage type" : "Vrsta pohrane",
    "Scope" : "Opseg",
    "Open documentation" : "Otvori dokumentaciju",
    "External storage enables you to mount external storage services and devices as secondary Nextcloud storage devices. You may also allow users to mount their own external storage services." : "Vanjska pohrana omogućuje vam postavljanje vanjskih servisa i uređaja za pohranu kao pomoćnih uređaja za pohranu sustava Nextcloud. Također možete omogućiti korisnicima postavljanje vlastitih vanjskih servisa za pohranu.",
    "Folder name" : "Naziv mape",
    "External storage" : "Vanjsko spremište za pohranu",
    "Authentication" : "Autentifikacija",
    "Configuration" : "Konfiguracija",
    "Available for" : "Dostupno za",
    "Click to recheck the configuration" : "Kliknite za ponovnu provjeru konfiguracije",
    "Add storage" : "Dodaj pohranu",
    "Advanced settings" : "Napredne postavke",
    "Allow users to mount external storage" : "Dopusti korisnicima postavljanje vanjske pohrane",
    "Global credentials can be used to authenticate with multiple external storages that have the same credentials." : "Globalne vjerodajnice mogu se upotrebljavati za provođenje autentifikacije na više vanjskih pohrana koje imaju iste vjerodajnice.",
    "Saving..." : "Spremanje..."
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");

==> nextcloud-31.0.7-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_external/l10n/hr.js <==
OC.L10N.register(
    "files_external",
    {
    "Grant access" : "Dodijeli pristup",
    "Error configuring OAuth1" : "Pogreška pri konfiguriranju OAuth1",
    "Please provide a valid app key and secret." : "Unesite važeći ključ aplikacije i tajnu.",
    "Error configuring OAuth2" : "Pogreška pri konfiguriranju OAuth2",
    "Generate keys" : "Generiraj ključeve",
    "Error generating key pair" : "Pogreška pri generiranju parova ključeva",
    "Storage with ID \"%d\" not found" : "Pohrana s ID-om „%d” nije pronađena",
    "Invalid backend or authentication mechanism class" : "Nevažeća klasa pozadine ili mehanizma autentifikacije",
    "Invalid mount point" : "Nevažeća točka postavljanja",
    "Objectstore forbidden" : "Zabranjen Objectstore",
    "Invalid storage backend \"%s\"" : "Nevažeća pozadina pohrane „%s”",
    "Not permitted to use backend \"%s\"" : "Nije dopušteno korištenje pozadine „%s”",
    "Not permitted to use authentication mechanism \"%s\"" : "Nije dopušteno korištenje mehanizma autentifikacije „%s”",
    "Unsatisfied backend parameters" : "Neispunjeni sigurnosni parametri",
    "Unsatisfied authentication mechanism parameters" : "Neispunjeni parametri mehanizma autentifikacije",
    "Insufficient data: %s" : "Nedovoljno podataka: %s",
    "%s" : "%s",
    "Access key" : "Pristupni ključ",
    "Secret key" : "Tajni ključ",
    "Builtin" : "Ugrađen",
    "None" : "Nema",
    "OAuth1" : "OAuth1",
    "App key" : "Ključ aplikacije",
    "App secret" : "Tajna aplikacije",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID klijenta",
    "Client secret" : "Tajni ključ klijenta",
    "OpenStack v2" : "OpenStack v2",
    "Login" : "Prijava",
    "Password" : "Zaporka",
    "Tenant name" : "Ime stanara",
    "Identity endpoint URL" : "URL krajnje točke identiteta",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Domena",
    "Rackspace" : "Rackspace",
    "API key" : "Ključ API-ja",
    "Global credentials" : "Globalne vjerodajnice",
    "Log-in credentials, save in database" : "Vjerodajnice za prijavu, spremi u bazu podataka",
    "Log-in credentials, save in session" : "Vjerodajnice za prijavu, spremi u sesiju",
    "RSA public key" : "Javni ključ RSA",
    "Public key" : "Javni ključ",
    "RSA private key" : "Privatni ključ RSA",
    "Private key" : "Privatni ključ",
    "Kerberos ticket" : "Kerberos ticket",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Naziv poslužitelja",
    "Port" : "Port",
    "Region" : "Regija",
    "Enable SSL" : "Omogući SSL",
    "Enable Path Style" : "Omogući Path Style",
    "Legacy (v2) authentication" : "Naslijeđena (v2) autentifikacija",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Udaljena podmapa",
    "Secure https://" : "Siguran https://",
    "FTP" : "FTP",
    "Host" : "Glavno računalo",
    "Secure ftps://" : "Siguran ftps://",
    "Local" : "Lokalno",
    "Location" : "Lokacija",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Korijen",
    "SFTP with secret key login" : "SFTP s prijavom putem tajnog ključa",
    "SMB/CIFS" : "SMB/CIFS",
    "Share" : "Dijeli",
    "Show hidden files" : "Prikaz skrivenih datoteka",
    "Verify ACL access when listing files" : "Provjeri ACL pristup pri pregledu popisa datoteka",
    "Timeout" : "Istek vremena",
    "SMB/CIFS using OC login" : "SMB/CIFS s prijavom putem OC-a",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Naziv servisa",
    "Request timeout (seconds)" : "Istek zahtjeva (u sekundama)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Podrška za cURL u PHP-u nije omogućena niti instalirana. Nije moguće postaviti %s. Zatražite od svog administratora sustava da je instalira.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Podrška za FTP u PHP-u nije omogućena niti instalirana. Nije moguće postaviti %s. Zatražite od svog administratora sustava da je instalira.",
    "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "„%1$s” nije instaliran. Nije moguće postaviti %2$s. Zatražite od svog administratora sustava da ga instalira.",
    "External storage" : "Vanjsko spremište za pohranu",
    "External storage support" : "Podrška za vanjsku pohranu",
    "Adds basic external storage support" : "Dodaje osnovnu podršku za vanjsku pohranu",
    "Confirm" : "Potvrdi",
    "External mount error" : "Pogreška vanjskog postavljanja",
    "Storage type" : "Vrsta pohrane",
    "Unknown" : "Nepoznata pogreška",
    "Scope" : "Opseg",
    "Personal" : "Osobno",
    "System" : "Sustav",
    "(Group)" : "(Grupa)",
    "Compatibility with Mac NFD encoding (slow)" : "Kompatibilnost s kodiranjem Mac NFD (sporo)",
    "Enable encryption" : "Omogući šifriranje",
    "Enable previews" : "Omogući pretpregled",
    "Enable sharing" : "Omogući dijeljenje",
    "Check for changes" : "Provjeri za promjene",
    "Never" : "Nikad",
    "Once every direct access" : "Jednom za svaki izravni pristup",
    "Read only" : "Samo za čitanje",
    "Disconnect" : "Odspoji",
    "Admin defined" : "Definira administrator",
    "Delete storage?" : "Želite li izbrisati pohranu?",
    "Click to recheck the configuration" : "Kliknite za ponovnu provjeru konfiguracije",
    "Saved" : "Spremljeno",
    "Saving …" : "Spremanje...",
    "Save" : "Spremi",
    "No external storage configured or you don't have the permission to configure them" : "Nema konfigurirane vanjske pohrane ili nemate dopuštenje za konfiguriranje",
    "Open documentation" : "Otvori dokumentaciju",
    "Folder name" : "Naziv mape",
    "Authentication" : "Autentifikacija",
    "Configuration" : "Konfiguracija",
    "Available for" : "Dostupno za",
    "Add storage" : "Dodaj pohranu",
    "Advanced settings" : "Napredne postavke",
    "Global credentials can be used to authenticate with multiple external storages that have the same credentials." : "Globalne vjerodajnice mogu se upotrebljavati za provođenje autentifikacije na više vanjskih pohrana koje imaju iste vjerodajnice."
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
